==> drupal_wall-7.x-2.4.tar.gz: drupal_wall/drupal_wall.js <==
jQuery(document).ready(function($) {

  jQuery('.drupal_wall_post_status #edit-shout-box-status-format').hide();
  jQuery('.drupal_wall_post_status #switch_edit-shout-box-status-value').hide();
  jQuery('.drupal_wall_post_status fieldset').hide();
  var drupal_wall_photos = jQuery("#drupal-wall-node-form input[name='field_drupal_wall_photos[und][0][fid]']").val();
  jQuery("#drupal-wall-node-form .form-item-field-drupal-wall-image-style-und-0-value").hide();
  jQuery("#drupal-wall-node-form .image-widget-data").hide();
  
  if (drupal_wall_photos == '0') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-image-style').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').show();
    
  }
  var drupal_wall_videos =  jQuery('#drupal-wall-node-form #edit-field-drupal-wall-videos-und-0-value').val();
  if (drupal_wall_videos == '') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').show();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-image-style').show();
  }
  else {
    jQuery("#drupal-wall-node-form input[name='field_drupal_wall_videos[und][0][value]").attr('disabled','disabled');
  }
  if (drupal_wall_photos == '0' && drupal_wall_videos == '') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').hide();
    jQuery("#drupal-wall-node-form .form-item-field-drupal-wall-image-style-und-0-value").hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').hide();
  }
  jQuery(document).ajaxComplete(function() {
    // Clear comment text field after save !
    jQuery('*[id^=edit-drupal-wall-comment]').val('');
  });
});

// Auto upload image & hide upload button.
(function ($) {
  Drupal.behaviors.autoUpload = {
    attach: function(context, settings) {
      $('.form-item input.form-submit[value=Upload]', context).hide();
      $('.form-item input.form-submit[value=Post]', context).hide();
      $('.form-item input.form-file', context).change(function() {
        $parent = $(this).closest('.form-item');

        setTimeout(function() {
          if(!$('.error', $parent).length) {
            $('input.form-submit[value=Upload]', $parent).mousedown();
          }
        }, 100);
      });
    }
  };
})(jQuery);

==> drupal_wall-7.x-2.5.tar.gz: drupal_wall/drupal_wall.js <==
jQuery(document).ready(function($) {

  jQuery('.drupal_wall_post_status #edit-shout-box-status-format').hide();
  jQuery('.drupal_wall_post_status #switch_edit-shout-box-status-value').hide();
  jQuery('.drupal_wall_post_status fieldset').hide();
  var drupal_wall_photos = jQuery("#drupal-wall-node-form input[name='field_drupal_wall_photos[und][0][fid]']").val();
  jQuery("#drupal-wall-node-form .form-item-field-drupal-wall-image-style-und-0-value").hide();
  jQuery("#drupal-wall-node-form .image-widget-data").hide();
  
  if (drupal_wall_photos == '0') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-image-style').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').show();
    
  }
  var drupal_wall_videos =  jQuery('#drupal-wall-node-form #edit-field-drupal-wall-videos-und-0-value').val();
  if (drupal_wall_videos == '') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').show();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-image-style').show();
  }
  else {
    jQuery("#drupal-wall-node-form #edit-field-drupal-wall-videos-und-0-value").attr('disabled','disabled');
    
  }
  if (drupal_wall_photos == '0' && drupal_wall_videos == '') {
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-photos').hide();
    jQuery("#drupal-wall-node-form .form-item-field-drupal-wall-image-style-und-0-value").hide();
    jQuery('#drupal-wall-node-form .field-name-field-drupal-wall-videos').hide();
  }
  jQuery(document).ajaxComplete(function() {
    // Clear comment text field after save !
    jQuery('*[id^=edit-drupal-wall-comment]').val('');
  });
});

// Auto upload image & hide upload button.
(function ($) {
  Drupal.behaviors.autoUpload = {
    attach: function(context, settings) {
      $('.form-item input.form-submit[value=Upload]', context).hide();
      $('.form-item input.form-submit[value=Post]', context).hide();
      $('.form-item input.form-file', context).change(function() {
        $parent = $(this).closest('.form-item');

        setTimeout(function() {
          if(!$('.error', $parent).length) {
            $('input.form-submit[value=Upload]', $parent).mousedown();
          }
        }, 100);
      });
    }
  };
})(jQuery);
